@@ -25,7 +25,7 @@ from calculate.lib.datavars import (Variable, VariableError,
                                     TableVariable, FieldValue,
                                     HumanReadable, CriticalError,
                                     SimpleDataVars, DataVarsError)
-from calculate.lib.utils.binhosts import Binhosts
+from calculate.lib.utils.binhosts import Binhosts, PackagesIndex, HOURS
 from calculate.lib.utils.files import readFile, listDirectory, process, pathJoin
 
 from calculate.lib.configparser import ConfigParser
@@ -40,6 +40,7 @@ from calculate.lib.variables import linux as lib_linux
 from calculate.lib.variables import env
 from calculate.update.update_info import UpdateInfo
 from itertools import chain
+from urlparse import urlparse
 import time
 
 _ = lambda x: x
@@ -1631,6 +1632,20 @@ class VariableClUpdateCheckRepSet(Variable):
         self.help = _("check and fix the repositories integrity")
 
 
+class VariableClUpdateForceFixSet(Variable):
+    """
+    Удлять лишние файлы из репозиториев (например созданные пользователем)
+    """
+    type = "bool"
+    value = "off"
+
+    opt = ["--force-fix"]
+
+    def init(self):
+        self.label = _("Force fix the settings")
+        self.help = _("force fix the settings")
+
+
 class VariableClUpdateOnedepthSet(Variable):
     """
     Удлять лишние файлы из репозиториев (например созданные пользователем)
@@ -1652,6 +1667,63 @@ class VariableClUpdateEixRepositories(ReadonlyVariable):
 
     def get(self):
         return ", ".join(
-            x.capitalize() for x in chain(
+            x.capitalize() for x in reversed(list(chain(
                 self.Get('update.cl_update_rep_name'),
-                self.Get('update.cl_update_other_rep_name')))
+                self.Get('update.cl_update_other_rep_name')))))
+
+
+class VariableClUpdatePortageBinhost(ReadonlyVariable):
+    """
+    Прописываемый в /etc/portage/make.conf/binhost репозиторий
+    """
+    value_format = "{update.cl_update_binhost}/grp/{os_arch_machine}"
+
+
+class VariableClUpdatePackageCache(ReadonlyVariable):
+    """
+    Путь кэшированного Packages
+    """
+    def get(self):
+        cache_path = "var/cache/edb"
+        chroot_path = self.Get('cl_chroot_path')
+        base_url = self.Get('cl_update_portage_binhost')
+        if not base_url:
+            return ""
+        parsed_url = urlparse(base_url)
+        host = parsed_url.netloc
+        port = parsed_url.port
+        user = None
+        passwd = None
+        user_passwd = ""
+        if "@" in host:
+            user, host = host.split("@", 1)
+            user_passwd = user + "@"
+            if ":" in user:
+                user, passwd = user.split(":", 1)
+        if port is not None:
+            port_str = ":%s" % (port,)
+            if host.endswith(port_str):
+                host = host[:-len(port_str)]
+        return os.path.join(chroot_path, cache_path, "binhost",
+                            host, parsed_url.path.lstrip("/"),
+                            "Packages")
+
+
+class VariableClUpdatePackageCacheSet(Variable):
+    """
+    Необходимость обновить Packages
+    """
+    type = "bool"
+
+    def get(self):
+        packages_fn = self.Get('cl_update_package_cache')
+        if not path.exists(packages_fn):
+            return "on"
+        pi = PackagesIndex(readFile(packages_fn))
+        try:
+            ttl = int(pi.get("TTL", "0"))
+            if ttl > HOURS:
+                return "off"
+        except ValueError:
+            return "on"
+        return "on"
